#!/usr/local/bin/perl
$ENV{"PATH"} .= ":/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/dba/tools:/opt/dbamon/bin";
#-------------------------------------------------------------------------
#
# Program: dbamon_hist.pl
#
#-------------------------------------------------------------------------
# Changes:
#   2012/09/01 BB: Added SD (suppressed duplicate) logic
#   2015/06/28 BB: Added SN (suppressed snoozed) logic
#-------------------------------------------------------------------------
$| = 1;
$P = "dbamon_hist.pl";
require "cgi_handlers.pl";

$maxrows       = 1000;

#---- Read WWW_Check:
chop($font = `grep 'WWW_Font:' /opt/dbamon/adm/dbamonrc | grep -v '^#' | awk '{ print \$2 }'`);
if ($font =~ /%/)
{
  $font =~ s/%/ /g;
  $font = "'$font'";
}
$font = "arial" if ! $font;

$f_s = "<font size=2 face=$font>";

push(@INC,"/opt/dbamon/lib");
require "subs.pl";
require "subsDB.pl";
require "subsWWW.pl";

#---- Trap an interrupt signal and clean up
$SIG{'INT'} = 'IntHandler';

use DBI;
require "cgi_handlers.pl";

chop($date     = `date`);
chop($host     = `hostname`);

#---- Save Company name
$compwork = `nslookup $host | grep Name: | awk '{ print \$2 }'` if -e '/etc/resolv.conf';
chop $compwork;
@words = split(/\./,$compwork);
$nexttolast = $#words - 1;
$company = $words[$nexttolast];

$database = "dbamon";

#---- See if DBAmon is configured to use Oracle
chop($use_oracle  = `grep Use_Oracle:  /opt/dbamon/adm/dbamonrc | awk '{ print \$2 }'`);
chop($ORACLE_SID  = `grep ORACLE_SID:  /opt/dbamon/adm/dbamonrc | awk '{ print \$2 }'`);
chop($ORACLE_HOME = `grep ORACLE_HOME: /opt/dbamon/adm/dbamonrc | awk '{ print \$2 }'`);
if ($use_oracle eq "Y" && $ORACLE_SID ne "" && $ORACLE_HOME ne "")
{
  $ENV{'ORACLE_SID'}  = $ORACLE_SID;
  $ENV{'ORACLE_HOME'} = $ORACLE_HOME;
  $user = "dbamon";
  chop($passwd = `grep 'ORACLE_Password:' /opt/dbamon/adm/dbamonrc | grep -v '^#' | awk '{ print \$2 }'`);
  $data_source = "DBI:Oracle";
  $database = $ORACLE_SID;
  $dbms = "oracle";
}
else
{
  $dbamon_repos = "M"; 
}

#------------------------------------------------------------------------------
sub msgOld
#------------------------------------------------------------------------------
{
  $msgmsg = $_[0];
  chop($date = `date +%Y/%m/%d-%H:%M:%S`);
  print "<br><font size=2>$date ${P} | <b>$msgmsg</b>\n";
}

#-----------------------------------------------------------------------------
sub displayError 
#-----------------------------------------------------------------------------
{
   local($errorMsg) = @_;

   print "Content-type: text/html\n\n";
   print "<head><title> Database Function Error - Output</title></head>";
   print "<body><font face=$font>";

   print "<h2> The following database error occured - $date</h2>";
   print "<hr noshade>";
   print "</hr noshade>";
   print "<h4> $errorMsg</h4>";
   $sqlerror = $DBI::errstr;
   print "<br>SQL statement: $statement";
   print "<br>SQL error: $sqlerror";

   &PrintLinks;

   print "</body>";
   print "</html>";

   exit(1);
}

#-----------------------------------------------------------------------------
sub connectDBOld
#-----------------------------------------------------------------------------
{
  $dbh = DBI->connect("$data_source:$database", $user, $passwd) ||
         &error('Failed_on_DB_connect_in_updateDb');
}

#-----------------------------------------------------------------------------
sub selectData
#-----------------------------------------------------------------------------
{
  $s_time = time;

  if ($this_sev eq "NSD")
  {
    $where2 = "and ticket != \'SD\' and ticket != 'SN' ";
    $where3 = "";
  }
  elsif ($this_sev ne "")
  {
    $where2 = "and sev = \'$this_sev\' ";
    $where3 = "";
  }
  else
  {
    $where2 = "";
    $where3 = "and ts >= sysdate - 183";
  }

  if ($dbamon_repos eq "O")
  {
    $statement  = "select 
	to_char(ts,'YYYY/MM/DD-HH24:MI:SS'), 
	instance, 
	system, 
	sev, 
	text,
	paged,
	ticket
      from 
	dbamon.events 
      where 
	instance = '$instance' 
	$where2
	and ts >= sysdate - 183
      order by ts desc
    ";
  }
  else
  {
    $statement  = "select 
	--to_char(ts,'YYYY/MM/DD-HH24:MI:SS'), 
	dbamon.dateconvert_19(ts), 
	instance, 
	system, 
	sev, 
	text,
	paged,
	ticket
      from 
	dbamon.dbamon.events 
      where 
	instance = '$instance' 
	$where2
	--and ts >= sysdate - 183
	 and datediff(day,ts,getdate()) <= 183
      order by ts desc
    ";
  }

  &msg("Querying DBAMON.EVENTS data for this instance for the last six months - SQL: $statement");

  $sth = $dbh->prepare($statement) ||
          &error('Failed_on_DB_prepare_in_chgEnt');
  $sth->execute || &error('Failed_on_DB_execute_in_chgEnt');

  $e_time = time;
  $elapsed = $e_time - $s_time;

  &msg("Query elapsed time: $elapsed seconds");

  print "<p><table border=0 bgcolor=wheat>\n";
  print "<tr bgcolor=cadetblue>
    <th>$f_s Event<br>Timestamp
    <th>$f_s Ticket Created (Y/N)? -or- Supression Status
    <th>$f_s Paged?
    <th>$f_s Event<br>Severity
    <th align=left>$f_s Event Text
    <th>$f_s Instance
    <th>$f_s Server
  ";

  $selectcount = 0;
  while (@Data = $sth->fetchrow_array)
  {
    $ts    = $Data[0];
    $in    = $Data[1];
    $sy    = $Data[2];
    $sev   = $Data[3];
    $text  = $Data[4];
    $paged = $Data[5];
    $ticket= $Data[6];

    $color = "white";

    if ($sev eq "C") { $pdesc = "Critical"; $color = "pink";   $fcolor = "black"}
    if ($sev eq "W") { $pdesc = "Warning "; $color = "yellow"; $fcolor = "black"}
    if ($sev eq "I") { $pdesc = "Info    "; $color = "cyan";   $fcolor = "black" }
    if ($sev eq "U") { $pdesc = "User    "; $color = "lime";   $fcolor = "black"}
    if ($sev eq "N") { $pdesc = "Notation"; $color = "gray";   $fcolor = "black"}
    if ($sev eq "S") { $pdesc = "Security"; $color = "mediumpurple";  $fcolor = "black"}
    if ($sev eq "P") { $pdesc = "Perf.   "; $color = "lightskyblue";  $fcolor = "black"}

    if ($company eq "thecompany" && length($ticket) > 1) 
    {
      $ticket_url = "<b><a href='blt_lookup.pl?$ticket'>$ticket</a>";
    }
    else
    {
      $ticket_url = $ticket;
    }

    if ($ticket eq "Y")  { $tcolor = $color;  } 
    else                 { $tcolor = "white"; } 
    if ($paged  eq "Y")  { $pcolor = $color;  } 
    else                 { $pcolor = "white"; } 

    if    ($ticket_url eq "SD")  { $rowcolor = "lightgray"; $pcolor = $rowcolor; $tcolor = $rowcolor; $ticket_desc = "(Suppressed-Dup)";  } 
    elsif ($ticket_url eq "SN")  { $rowcolor = "lightgray"; $pcolor = $rowcolor; $tcolor = $rowcolor; $ticket_desc = "(Suppressed-Snoozed)";  } 
    elsif ($ticket_url eq "SI")  { $rowcolor = "lightgray"; $pcolor = $rowcolor; $tcolor = $rowcolor; $ticket_desc = "(Suppressed-Inh)";  } 
    else                      { $rowcolor = "white"; $ticket_desc = "";  } 

    $fs = "2 face=$font";
    $f_s = "<font size=2 face=$font>";

    print "<tr bgcolor=$rowcolor>
      <td nowrap><font size=$fs color=$fcolor><b>$ts </b></font>
      <td nowrap bgcolor=$tcolor><font size=$fs color=$fcolor>$ticket_url $ticket_desc</font>
      <td bgcolor=$pcolor><font size=$fs color=$fcolor>$paged &nbsp; </font>
      <td nowrap bgcolor=$color><font size=$fs color=$fcolor>$sev ($pdesc) </font>
      <td nowrap bgcolor=$color><b><font size=$fs color=$fcolor>$text</font>
      <td><font size=$fs color=$fcolor>$in</font>
      <td><font size=$fs color=$fcolor>$sy</font>
    "; 

    if (++$selectcount > $maxrows) 
    { 
      print "<tr bgcolor=pink><td colspan=99><b><font size=2>MaxRows threshold of $maxrows exceeded\n";
      print "</table>\n";
      return; 
    }
  }

  if ($selectcount == 0) 
  { 
    print "<tr bgcolor=white><td colspan=5><b>No event history data found for instance: $instance\n";
  }
  print "</table>\n";
  &msg("Rows Selected: $selectcount");
}

#-----------------------------------------------------------------------------
sub IntHandler
#-----------------------------------------------------------------------------
{
   local($Signal) = @_;
   print "Signal=$Signal\n";
   exit(0);
}

#-----------------------------------------------------------------------------
sub error_html 
#-----------------------------------------------------------------------------
{
   $manyerrors = @error_list;
   $str= "" ;
   $str1="";
   $str2="";
   $str4=" <h2>Insufficient or missing information...</h2>";
   $html_str=$str.$str1.$str2.$str1.$str4;
   print "$html_str\n";
   #print "<h2>Insufficient or missing information...";
   print "<br>\n";
   print "Please correct the following:</h2>";
   print "<p>\n";
   print "<hr><ul>\n";
   foreach( @error_list) {
      print "<li> $_\n<br>";
   }
   print "</ul>\n";
   print "<hr>\n";
   if ($manyerrors > 3) {
      print "$manyerrors errors - Having a bad day, are we?<p>\n";
   }
   else {
      print "$manyerrors corrections to make.<p>\n";
   }
      
}

#-----------------------------------------------------------------------------
sub custom_html 
#-----------------------------------------------------------------------------
{

   print "<h1>Thank you for using this input form.</h1>";
   print "<h2>Your request has been sent.</h2>";
   print "<p><hr>\n";
}

#-----------------------------------------------------------------------------
sub CheckForEvilness
#-----------------------------------------------------------------------------
{
  local($woid2check) = @_;
  if (($woid2check =~ /\//) ||
      ($woid2check =~ /\;/) ||
      ($woid2check =~ /\</) ||
      ($woid2check =~ /\>/) ||
      ($woid2check =~ /\*/) ||
      ($woid2check =~ /\|/) ||
      ($woid2check =~ /\'/) ||
      ($woid2check =~ /\&/) ||
      ($woid2check =~ /\!/) ||
      ($woid2check =~ /\#/) ||
      ($woid2check =~ /\(/) ||
      ($woid2check =~ /\)/) ||
      ($woid2check =~ /\[/) ||
      ($woid2check =~ /\]/) ||
      ($woid2check =~ /\{/) ||
      ($woid2check =~ /\}/) ||
      ($woid2check =~ /\:/) ||
      ($woid2check =~ /\'/) ||
      ($woid2check =~ /\//) ||
      ($woid2check =~ /\n/) ||
      ($woid2check =~ /\"/))
        {
          print "Content-type: text/html\n\n";
          print "You have entered spurious control characters in a field.\n";
          print "You cannot use any of the following characters:\n";
          print " ;<>*|\'&!#()[]{}:\'/\"";
          print "\n The entry that is suspect is [$woid2check]\n";
          print "Please retry...\n";
          exit;
         }
}

#-----------------------------------------------------------------------------
#
# Main
#
#-----------------------------------------------------------------------------

$logfile = "/tmp/dbamon_hist.log";
unlink($logfile);
chop($CurrentDate = `date`);

&get_request;

@words = split(/,/,$ARGV[0]);
$instance = $words[0];
$prodtest = $words[1];
$this_sev = $words[2];

if ($prodtest eq "test")
{
  $db = "dbamon_test";
}
else
{
  $db = "dbamon";
}

open(LOG, ">>$logfile" );
print LOG "$CurrentDate - $P dbms=$dbms prodtest=$prodtest\n";

&header("Event History - Instance: $instance") unless $ENV{'DBAMON_NOWEB'};

#---- Display menu
print "<table bgcolor=black>
<tr align=center>
  <td><font size=1><font color=white> Filter: </font>
    <a href='/cgi-bin/dbamon_hist.pl?$instance,$prodtest,C'><font color=red   ><b>Critical Events Only</b></font></a> 
    <a href='/cgi-bin/dbamon_hist.pl?$instance,$prodtest,W'><font color=yellow><b>Warning Events Only</b></font></a> 
    <a href='/cgi-bin/dbamon_hist.pl?$instance,$prodtest,I'><font color=cyan  ><b>Info Events Only</b></font></a> 
    <a href='/cgi-bin/dbamon_hist.pl?$instance,$prodtest,U'><font color=green ><b>User Events Only</b></font></a> 
    <a href='/cgi-bin/dbamon_hist.pl?$instance,$prodtest,NSD'><font color=white ><b>Exclude SD and SN Events</b></font></a> 
</table>
";

&msg("Starting - maxrows=$maxrows this_sev=$this_sev");

#---- Connect to DB
&connectDB;

#---- Connect to DB
&selectData;

&msg("Done");
close(LOG);
exit 0;
