# -----------------------------------------------------------------------------
sub oraInSync
# -----------------------------------------------------------------------------
{
  ($thishost) = @_;

  if ($up[$thishost] ne "Y")
  {
    &logit("(Down/Inhibited)",$thishost);
    return 1; 
  }
    
  # Return if they don't want age checking for this instance
  if ($is_threshold[$thishost] eq "")
  {
    logit("Standby Sync Aging not requested for this instance",$thishost);
    return 0;
  }

  #---- BB 13Jun04 - Return if this DB is not in sby mode
  if ($standby[$thishost] ne "STANDBY")
  {
    &event("U",$thishost,"InSync Checking only works for DBs that are in STANDBY mode - standby=$standby[$thishost]","InSyncNotSbyMode","DBA669");
    return 0;
  }

  $parm = "$probe[$thishost] inSyncSby $is_prihost[$thishost] $is_prisid[$thishost]";

  ##print "parm=$parm \n";
  &remsh($parm,$tmpfl3,$thishost);
  ##system("cat $tmpfl3");

  #See if auto-inhibit occured
  if ($up[$thishost] eq "I")
  {
    logit("(Auto-Inhibited)",$thishost);
    return;
  }

  &logDetails($thishost,"<h3>Oracle Standby-Primary Synchronization</h3>");
  &logDetails($thishost,"<table border=1 bgcolor=antiquewhite>");
  &logDetails($thishost,"<tr bgcolor=slate><th>Parameter<th>Value (Minutes)<th>Comments</tr>");

  $pri   = "";
  $sby   = "";
  $delta = "";
  $priup = "?";
  $priunrec = "";
  $nologobj = 0;

  open(TMPFL3, "$tmpfl3") || &error_msg("Can't open input $tmpfl3 - $!");
  while (<TMPFL3>)
  {
    &parse;
    if ($F1 eq "INSYNC:")
    {
      if ($F2 eq "SBY")      { $sby = $F3; }
      if ($F2 eq "PRI")      { $pri = $F3; }
      if ($F2 eq "NOLOG")    { $nologobj++; }
      if ($F2 eq "PRIUP")    { $priup = $F3; }
      if ($F2 eq "PRIUNREC") { $priunrec = $F3; }
      if ($F2 eq "DELTA")    
      { 
        $delta = $F3; 
        $mr_delta[$thishost] = $delta; 
      }
    }
  }
  close(TMPFL3);

  &logDetails($thishost,"<tr><td><b>$f_s Current Age of Standby Controlfile:</b><td align=right>$f_s $sby");
  &logDetails($thishost,"<tr><td><b>$f_s Current Age of Primary Controlfile:</b><td align=right>$f_s $pri");
  &logDetails($thishost,"<tr><td><b>$f_s Delta:</b><td align=right>$f_s $delta");
  &logDetails($thishost,"<tr><td><b>$f_s Threshold:</b><td align=right>$f_s $is_threshold[$thishost]");
  &logDetails($thishost,"<tr><td><b>$f_s Primary DB Up?:</b><td>$f_s $priup");
  &logDetails($thishost,"</table><hr>");

  if ($nologobj > 0)
  {
    if ($force_logging[$thishost] eq "YES")
    {
      $znmsg = "$nologobj NOLOGGING Object(s) Found On Primary DB $is_prihost[$thishost]/$is_prisid[$thishost] - However Forced Logging is YES, so no action is requried";
      &logit($znmsg,$thishost);
    }
    else
    {
      $znmsg = "$nologobj NOLOGGING Object(s) Found On Primary DB $is_prihost[$thishost]/$is_prisid[$thishost]";
      &event("$is_nolog_sev[$thishost]",$thishost,"$znmsg","InSyncNOLOG","DBA666",$tmpfl3);

      # Debug
      ##$zz = `cat $tmpfl3`;
      ##system("echo '$zz' | dbamon_mailer -m -s 'DBAmon $titleraw[$thishost] $znmsg' $admin_email");
    }
  }

  if ($priup ne "Y")
  {
    $znmsg = "Primary DB $is_prihost[$thishost]/$is_prisid[$thishost] is DOWN (SQL will not run)";
    &event("C",$thishost,"$znmsg","InSyncPriDown","DBA667",$tmpfl3);

    # Debug
    $zz = `cat $tmpfl3`;
    system("echo '$zz' | dbamon_mailer -m -s 'DBAmon $title[$thishost] $znmsg' $admin_email");
  }

  if ($priunrec ne "")
  {
    $znmsg = "Primary DB Has $priunrec datafile(s) with UNRECOVERABLE changes since the last standby rebuild";

    #if ($is_unrec_sev[$thishost] eq "C")
    #{
    #  $znsev = "C";  
    #}
    #else
    #{
    #  $znsev = "W";  
    #}
    if ($is_unrec_sev[$thishost] eq "W")
    {
      $znsev = "W";  
    }
    else
    {
      $znsev = "C";  
    }

    &event("$znsev",$thishost,"$znmsg","InSyncUnrecDFs","DBA668",$tmpfl3);

    # Debug
    $zz = `cat $tmpfl3`;
    system("echo '$zz' | dbamon_mailer -m -s 'DBAmon sev=$znsev $titleraw[$thishost] $znmsg' $debug_email");
  }

  if ($delta > $is_threshold[$thishost])
  {
    $znmsg = "This Standby DB is $delta Minutes Behind Primary (Threshold is $is_threshold[$thishost])";
    &event("C",$thishost,"$znmsg","InSyncAge","DBA665",$tmpfl3);

    # Debug
    $zz = `cat $tmpfl3`;
    system("echo '$zz' | dbamon_mailer -m -s 'DBAmon $title[$thishost] $znmsg' $debug_email");
  }
  else
  {
    &logit("OK - StandbyDelta=$delta Threshold=$is_threshold[$thishost]",$thishost);
  }
  
  # Log to history file
  chop($date = `date +%Y/%m/%d-%H:%M:%S`);
  system("echo '$title[$thishost] $date $delta' >> /opt/dbamon/dat/history/insync.dat");
}
# -----------------------------------------------------------------------------
1;
